diff --git a/core/modules/aggregator/lib/Drupal/aggregator/Tests/AggregatorRenderingTest.php b/core/modules/aggregator/lib/Drupal/aggregator/Tests/AggregatorRenderingTest.php
index 464c4f2..380e553 100644
--- a/core/modules/aggregator/lib/Drupal/aggregator/Tests/AggregatorRenderingTest.php
+++ b/core/modules/aggregator/lib/Drupal/aggregator/Tests/AggregatorRenderingTest.php
@@ -17,7 +17,7 @@ class AggregatorRenderingTest extends AggregatorTestBase {
    *
    * @var array
    */
-  public static $modules = array('block');
+  public static $modules = array('block', 'test_page_test');
 
   public static function getInfo() {
     return array(
@@ -53,7 +53,7 @@ public function testBlockLinks() {
     $block = $this->drupalPlaceBlock("aggregator_feed_block:{$feed->id()}", array('label' => 'feed-' . $feed->label()), array('block_count' => 2));
 
     // Confirm that the block is now being displayed on pages.
-    $this->drupalGet('node');
+    $this->drupalGet('test-page');
     $this->assertText($block->label(), 'Feed block is displayed on the page.');
 
     // Find the expected read_more link.
@@ -71,7 +71,7 @@ public function testBlockLinks() {
     $feed->block = 0;
     $feed->save();
     // Check that the block is no longer displayed.
-    $this->drupalGet('node');
+    $this->drupalGet('test-page');
     $this->assertNoText($block->label(), 'Feed block is not displayed on the page when number of items is set to 0.');
   }
 
diff --git a/core/modules/comment/lib/Drupal/comment/Tests/CommentInterfaceTest.php b/core/modules/comment/lib/Drupal/comment/Tests/CommentInterfaceTest.php
index 24a7931..bda6368 100644
--- a/core/modules/comment/lib/Drupal/comment/Tests/CommentInterfaceTest.php
+++ b/core/modules/comment/lib/Drupal/comment/Tests/CommentInterfaceTest.php
@@ -109,10 +109,6 @@ function testCommentInterface() {
     $reply = $this->postComment(NULL, $this->randomName(), $this->randomName(), TRUE);
     $this->assertTrue($this->commentExists($reply, TRUE), 'Modified reply found.');
 
-    // Correct link count
-    $this->drupalGet('node');
-    $this->assertRaw('4 comments', 'Link to the 4 comments exist.');
-
     // Confirm a new comment is posted to the correct page.
     $this->setCommentsPerPage(2);
     $comment_new_page = $this->postComment($this->node, $this->randomName(), $this->randomName(), TRUE);
diff --git a/core/modules/comment/lib/Drupal/comment/Tests/CommentLinksTest.php b/core/modules/comment/lib/Drupal/comment/Tests/CommentLinksTest.php
index 91cab48..84c3f10 100644
--- a/core/modules/comment/lib/Drupal/comment/Tests/CommentLinksTest.php
+++ b/core/modules/comment/lib/Drupal/comment/Tests/CommentLinksTest.php
@@ -12,6 +12,15 @@
  */
 class CommentLinksTest extends CommentTestBase {
 
+  /**
+   * Use the main node listing to test rendering on teasers.
+   *
+   * @var array
+   *
+   * @todo Remove this dependency.
+   */
+  public static $modules = array('views');
+
   public static function getInfo() {
     return array(
       'name' => 'Comment links',
diff --git a/core/modules/comment/lib/Drupal/comment/Tests/CommentNewIndicatorTest.php b/core/modules/comment/lib/Drupal/comment/Tests/CommentNewIndicatorTest.php
index 324012e..8009f88 100644
--- a/core/modules/comment/lib/Drupal/comment/Tests/CommentNewIndicatorTest.php
+++ b/core/modules/comment/lib/Drupal/comment/Tests/CommentNewIndicatorTest.php
@@ -12,6 +12,15 @@
  */
 class CommentNewIndicatorTest extends CommentTestBase {
 
+  /**
+   * Use the main node listing to test rendering on teasers.
+   *
+   * @var array
+   *
+   * @todo Remove this dependency.
+   */
+  public static $modules = array('views');
+
   public static function getInfo() {
     return array(
       'name' => "Comment 'new' indicator",
diff --git a/core/modules/contextual/lib/Drupal/contextual/Tests/ContextualDynamicContextTest.php b/core/modules/contextual/lib/Drupal/contextual/Tests/ContextualDynamicContextTest.php
index da786a2..f84e9f4 100644
--- a/core/modules/contextual/lib/Drupal/contextual/Tests/ContextualDynamicContextTest.php
+++ b/core/modules/contextual/lib/Drupal/contextual/Tests/ContextualDynamicContextTest.php
@@ -19,7 +19,7 @@ class ContextualDynamicContextTest extends WebTestBase {
    *
    * @var array
    */
-  public static $modules = array('contextual', 'node');
+  public static $modules = array('contextual', 'node', 'views');
 
   public static function getInfo() {
     return array(
diff --git a/core/modules/locale/lib/Drupal/locale/Tests/LocaleContentTest.php b/core/modules/locale/lib/Drupal/locale/Tests/LocaleContentTest.php
index 67c4eb4..a4768ac 100644
--- a/core/modules/locale/lib/Drupal/locale/Tests/LocaleContentTest.php
+++ b/core/modules/locale/lib/Drupal/locale/Tests/LocaleContentTest.php
@@ -179,9 +179,9 @@ function testContentTypeDirLang() {
       ));
     }
 
-    $this->drupalGet('node');
 
     // Check if English node does not have lang tag.
+    $this->drupalGet('node/' . $nodes['en']->nid);
     $pattern = '|id="node-' . $nodes['en']->nid . '"[^<>]*lang="en"|';
     $this->assertNoPattern($pattern, 'The lang tag has not been assigned to the English node.');
 
@@ -190,18 +190,18 @@ function testContentTypeDirLang() {
     $this->assertNoPattern($pattern, 'The dir tag has not been assigned to the English node.');
 
     // Check if Arabic node has lang="ar" & dir="rtl" tags.
+    $this->drupalGet('node/' . $nodes['ar']->nid);
     $pattern = '|id="node-' . $nodes['ar']->nid . '"[^<>]*lang="ar" dir="rtl"|';
     $this->assertPattern($pattern, 'The lang and dir tags have been assigned correctly to the Arabic node.');
 
     // Check if Spanish node has lang="es" tag.
+    $this->drupalGet('node/' . $nodes['es']->nid);
     $pattern = '|id="node-' . $nodes['es']->nid . '"[^<>]*lang="es"|';
     $this->assertPattern($pattern, 'The lang tag has been assigned correctly to the Spanish node.');
 
     // Check if Spanish node does not have dir="ltr" tag.
     $pattern = '|id="node-' . $nodes['es']->nid . '"[^<>]*lang="es" dir="ltr"|';
     $this->assertNoPattern($pattern, 'The dir tag has not been assigned to the Spanish node.');
-
-    $this->drupalLogout();
   }
 
 
diff --git a/core/modules/locale/lib/Drupal/locale/Tests/LocalePathTest.php b/core/modules/locale/lib/Drupal/locale/Tests/LocalePathTest.php
index d1ad5f0..4f49d02 100644
--- a/core/modules/locale/lib/Drupal/locale/Tests/LocalePathTest.php
+++ b/core/modules/locale/lib/Drupal/locale/Tests/LocalePathTest.php
@@ -19,7 +19,7 @@ class LocalePathTest extends WebTestBase {
    *
    * @var array
    */
-  public static $modules = array('node', 'locale', 'path');
+  public static $modules = array('node', 'locale', 'path', 'views');
 
   public static function getInfo() {
     return array(
diff --git a/core/modules/menu/lib/Drupal/menu/Tests/MenuTest.php b/core/modules/menu/lib/Drupal/menu/Tests/MenuTest.php
index 75532b0..143f99e 100644
--- a/core/modules/menu/lib/Drupal/menu/Tests/MenuTest.php
+++ b/core/modules/menu/lib/Drupal/menu/Tests/MenuTest.php
@@ -16,7 +16,7 @@ class MenuTest extends WebTestBase {
    *
    * @var array
    */
-  public static $modules = array('menu', 'block');
+  public static $modules = array('menu', 'block', 'test_page_test');
 
   protected $big_user;
   protected $std_user;
@@ -262,14 +262,14 @@ function testMenuQueryAndFragment() {
     $this->drupalLogin($this->big_user);
 
     // Make a path with query and fragment on.
-    $path = 'node?arg1=value1&arg2=value2';
+    $path = 'test-page?arg1=value1&arg2=value2';
     $item = $this->addMenuLink(0, $path);
 
     $this->drupalGet('admin/structure/menu/item/' . $item['mlid'] . '/edit');
     $this->assertFieldByName('link_path', $path, 'Path is found with both query and fragment.');
 
     // Now change the path to something without query and fragment.
-    $path = 'node';
+    $path = 'test-page';
     $this->drupalPost('admin/structure/menu/item/' . $item['mlid'] . '/edit', array('link_path' => $path), t('Save'));
     $this->drupalGet('admin/structure/menu/item/' . $item['mlid'] . '/edit');
     $this->assertFieldByName('link_path', $path, 'Path no longer has query or fragment.');
diff --git a/core/modules/node/config/views.view.frontpage.yml b/core/modules/node/config/views.view.frontpage.yml
new file mode 100644
index 0000000..a6a8be2
--- /dev/null
+++ b/core/modules/node/config/views.view.frontpage.yml
@@ -0,0 +1,145 @@
+base_field: nid
+base_table: node
+core: 8.x
+description: 'A list of nodes marked for display on the front page.'
+status: '1'
+display:
+  default:
+    display_options:
+      access:
+        type: perm
+      cache:
+        type: none
+      empty:
+        area:
+          admin_label: ''
+          content: 'No front page content has been created yet.'
+          empty: '1'
+          field: area
+          format: plain_text
+          group_type: group
+          id: area
+          label: ''
+          relationship: none
+          table: views
+          tokenize: '0'
+          plugin_id: text
+        node_listing_empty:
+          admin_label: ''
+          empty: '1'
+          field: node_listing_empty
+          group_type: group
+          id: node_listing_empty
+          label: ''
+          relationship: none
+          table: node
+          plugin_id: node_listing_empty
+        title:
+          id: title
+          table: views
+          field: title
+          relationship: none
+          group_type: group
+          admin_label: ''
+          label: ''
+          empty: '1'
+          title: 'Welcome to Drupal'
+          plugin_id: title
+      exposed_form:
+        type: basic
+      filters:
+        promote:
+          admin_label: ''
+          expose:
+            description: ''
+            identifier: ''
+            label: ''
+            multiple: '0'
+            operator: ''
+            operator_id: '0'
+            remember: '0'
+            remember_roles:
+              authenticated: authenticated
+            required: '0'
+            use_operator: '0'
+          exposed: '0'
+          field: promote
+          group: '1'
+          group_info:
+            default_group: All
+            default_group_multiple: {  }
+            description: ''
+            group_items: {  }
+            identifier: ''
+            label: ''
+            multiple: '0'
+            optional: '1'
+            remember: '0'
+            widget: select
+          group_type: group
+          id: promote
+          is_grouped: '0'
+          operator: '='
+          relationship: none
+          table: node
+          value: '1'
+          plugin_id: boolean
+        status:
+          expose:
+            operator: '0'
+          field: status
+          group: '1'
+          id: status
+          table: node
+          value: '1'
+          plugin_id: boolean
+      pager:
+        options:
+          items_per_page: '10'
+        type: full
+      query:
+        type: views_query
+      row:
+        options:
+          build_mode: teaser
+          comments: '0'
+          links: '1'
+        type: node
+      sorts:
+        created:
+          field: created
+          id: created
+          order: DESC
+          table: node
+          plugin_id: date
+        sticky:
+          admin_label: ''
+          expose:
+            label: ''
+          exposed: '0'
+          field: sticky
+          group_type: group
+          id: sticky
+          order: ASC
+          relationship: none
+          table: node
+          plugin_id: boolean
+      style:
+        type: default
+      title: ''
+    display_plugin: default
+    display_title: Master
+    id: default
+    position: {  }
+  page_1:
+    display_options:
+      path: node
+    display_plugin: page
+    display_title: Page
+    id: page_1
+    position: {  }
+human_name: Frontpage
+langcode: und
+module: node
+id: frontpage
+tag: ''
diff --git a/core/modules/node/lib/Drupal/node/Plugin/views/area/ListingEmpty.php b/core/modules/node/lib/Drupal/node/Plugin/views/area/ListingEmpty.php
new file mode 100644
index 0000000..4e94920
--- /dev/null
+++ b/core/modules/node/lib/Drupal/node/Plugin/views/area/ListingEmpty.php
@@ -0,0 +1,44 @@
+<?php
+
+/**
+ * @file
+ * Contains \Drupal\node\Plugin\views\area\LinkAdd.
+ */
+
+namespace Drupal\node\Plugin\views\area;
+
+use Drupal\Core\Annotation\Plugin;
+use Drupal\views\Plugin\views\area\AreaPluginBase;
+
+/**
+ * Defines an area plugin to display a node/add link.
+ *
+ * @ingroup views_area_handlers
+ *
+ * @Plugin(
+ *   id = "node_listing_empty",
+ *   module = "node"
+ * )
+ */
+class ListingEmpty extends AreaPluginBase {
+
+  /**
+   * Implements \Drupal\views\Plugin\views\area\AreaPluginBase::render().
+   */
+  public function render($empty = FALSE) {
+    if (!$empty || !empty($this->options['empty'])) {
+      $element = array(
+        '#theme' => 'links',
+        '#links' => array(
+          array(
+            'href' => 'node/add',
+            'title' => t('Add new content')
+          )
+        ) ,
+        '#access' => _node_add_access()
+      );
+      return drupal_render($element);
+    }
+  }
+
+}
diff --git a/core/modules/node/lib/Drupal/node/Tests/NodeLoadMultipleTest.php b/core/modules/node/lib/Drupal/node/Tests/NodeLoadMultipleTest.php
index 25cb01d..ad37c69 100644
--- a/core/modules/node/lib/Drupal/node/Tests/NodeLoadMultipleTest.php
+++ b/core/modules/node/lib/Drupal/node/Tests/NodeLoadMultipleTest.php
@@ -12,6 +12,13 @@
  */
 class NodeLoadMultipleTest extends NodeTestBase {
 
+  /**
+   * Enable Views to test the frontpage against node_load_multiple() results.
+   *
+   * @var array
+   */
+  public static $modules = array('views');
+
   public static function getInfo() {
     return array(
       'name' => 'Load multiple nodes',
diff --git a/core/modules/node/lib/Drupal/node/Tests/NodeTitleTest.php b/core/modules/node/lib/Drupal/node/Tests/NodeTitleTest.php
index e657d76..e03e4b0 100644
--- a/core/modules/node/lib/Drupal/node/Tests/NodeTitleTest.php
+++ b/core/modules/node/lib/Drupal/node/Tests/NodeTitleTest.php
@@ -17,7 +17,7 @@ class NodeTitleTest extends NodeTestBase {
    *
    * @var array
    */
-  public static $modules = array('comment');
+  public static $modules = array('comment', 'views');
 
   protected $admin_user;
 
diff --git a/core/modules/node/node.module b/core/modules/node/node.module
index f2206a0..03ef9ba 100644
--- a/core/modules/node/node.module
+++ b/core/modules/node/node.module
@@ -1713,13 +1713,6 @@ function node_menu() {
     'access arguments' => array('administer content types'),
     'file' => 'content_types.inc',
   );
-
-  $items['node'] = array(
-    'page callback' => 'node_page_default',
-    'access arguments' => array('access content'),
-    'menu_name' => 'tools',
-    'type' => MENU_CALLBACK,
-  );
   $items['node/add'] = array(
     'title' => 'Add content',
     'page callback' => 'node_add_page',
@@ -2196,62 +2189,6 @@ function node_view_multiple($nodes, $view_mode = 'teaser', $langcode = NULL) {
 }
 
 /**
- * Page callback: Generates a listing of promoted nodes.
- *
- * @return array
- *   An array in the format expected by drupal_render().
- *
- * @see node_menu()
- */
-function node_page_default() {
-  $site_config = config('system.site');
-  $select = db_select('node', 'n')
-    ->fields('n', array('nid', 'sticky', 'created'))
-    ->condition('n.promote', 1)
-    ->condition('n.status', 1)
-    ->orderBy('n.sticky', 'DESC')
-    ->orderBy('n.created', 'DESC')
-    ->extend('Drupal\Core\Database\Query\PagerSelectExtender')
-    ->limit(config('node.settings')->get('items_per_page'))
-    ->addTag('node_access');
-
-  $nids = $select->execute()->fetchCol();
-
-  if (!empty($nids)) {
-    $nodes = node_load_multiple($nids);
-    $build['nodes'] = node_view_multiple($nodes);
-
-    // 'rss.xml' is a path, not a file, registered in node_menu().
-    drupal_add_feed('rss.xml', $site_config->get('name') . ' ' . t('RSS'));
-    $build['pager'] = array(
-      '#theme' => 'pager',
-      '#weight' => 5,
-    );
-    drupal_set_title('');
-  }
-  else {
-    drupal_set_title(t('Welcome to @site-name', array('@site-name' => $site_config->get('name'))), PASS_THROUGH);
-
-    $default_message = '<p>' . t('No front page content has been created yet.') . '</p>';
-
-    $default_links = array();
-    if (_node_add_access()) {
-      $default_links[] = l(t('Add new content'), 'node/add');
-    }
-    if (!empty($default_links)) {
-      $default_message .= theme('item_list', array('items' => $default_links));
-    }
-
-    $build['default_message'] = array(
-      '#markup' => $default_message,
-      '#prefix' => '<div id="first-time">',
-      '#suffix' => '</div>',
-    );
-  }
-  return $build;
-}
-
-/**
  * Page callback: Displays a single node.
  *
  * @param Drupal\node\Node $node
diff --git a/core/modules/node/node.views.inc b/core/modules/node/node.views.inc
index cd6575e..0c232a2 100644
--- a/core/modules/node/node.views.inc
+++ b/core/modules/node/node.views.inc
@@ -420,6 +420,14 @@ function node_views_data() {
     ),
   );
 
+  $data['node']['node_listing_empty'] = array(
+    'title' => t('Empty Node Frontpage behavior'),
+    'help' => t('Provides a link to the node add overview page.'),
+    'area' => array(
+      'id' => 'node_listing_empty',
+    ),
+  );
+
   // Content revision table
 
   // Define the base group of this table. Fields that don't
diff --git a/core/modules/rdf/lib/Drupal/rdf/Tests/CommentAttributesTest.php b/core/modules/rdf/lib/Drupal/rdf/Tests/CommentAttributesTest.php
index bce0f35..dbdba31 100644
--- a/core/modules/rdf/lib/Drupal/rdf/Tests/CommentAttributesTest.php
+++ b/core/modules/rdf/lib/Drupal/rdf/Tests/CommentAttributesTest.php
@@ -19,7 +19,7 @@ class CommentAttributesTest extends CommentTestBase {
    *
    * @var array
    */
-  public static $modules = array('comment', 'rdf');
+  public static $modules = array('views', 'node', 'comment', 'rdf');
 
   public static function getInfo() {
     return array(
diff --git a/core/modules/views/config/views.view.frontpage.yml b/core/modules/views/config/views.view.frontpage.yml
deleted file mode 100644
index 638387c..0000000
--- a/core/modules/views/config/views.view.frontpage.yml
+++ /dev/null
@@ -1,98 +0,0 @@
-status: '0'
-module: node
-id: frontpage
-description: 'Emulates the default Drupal front page; you may set the default home page path to this view to make it your front page.'
-tag: default
-base_table: node
-human_name: 'Front page'
-core: '8'
-display:
-  default:
-    id: default
-    display_title: Master
-    display_plugin: default
-    position: '1'
-    display_options:
-      query:
-        type: views_query
-        options:
-          query_comment: false
-      access:
-        type: none
-      cache:
-        type: none
-      exposed_form:
-        type: basic
-      pager:
-        type: full
-      style:
-        type: default
-      row:
-        type: node
-        options:
-          links: 1
-      sorts:
-        sticky:
-          id: sticky
-          table: node
-          field: sticky
-          order: DESC
-          plugin_id: standard
-        created:
-          id: created
-          table: node
-          field: created
-          order: DESC
-          plugin_id: date
-      filters:
-        promote:
-          id: promote
-          table: node
-          field: promote
-          value: '1'
-          group: 0
-          expose:
-            operator: false
-          plugin_id: boolean
-        status:
-          id: status
-          table: node
-          field: status
-          value: '1'
-          group: 0
-          expose:
-            operator: false
-          plugin_id: boolean
-  page_1:
-    id: page_1
-    display_title: Page
-    display_plugin: page
-    position: '2'
-    display_options:
-      query:
-        type: views_query
-        options: {  }
-      path: frontpage
-  feed_1:
-    id: feed_1
-    display_title: Feed
-    display_plugin: feed
-    position: '3'
-    display_options:
-      query:
-        type: views_query
-        options: {  }
-      defaults:
-        title: false
-      title: 'Front page feed'
-      pager:
-        type: some
-      style:
-        type: rss
-      row:
-        type: node_rss
-      path: rss.xml
-      displays:
-        default: default
-        page: page
-      sitename_title: '1'
diff --git a/core/modules/views/lib/Drupal/views/Tests/AnalyzeTest.php b/core/modules/views/lib/Drupal/views/Tests/AnalyzeTest.php
index cd0e317..e01bf7b 100644
--- a/core/modules/views/lib/Drupal/views/Tests/AnalyzeTest.php
+++ b/core/modules/views/lib/Drupal/views/Tests/AnalyzeTest.php
@@ -19,6 +19,13 @@ class AnalyzeTest extends ViewTestBase {
    */
   public static $modules = array('views_ui');
 
+  /**
+   * Views used by this test.
+   *
+   * @var array
+   */
+  public static $testViews = array('test_view');
+
   public static function getInfo() {
     return array(
       'name' => 'Views Analyze',
@@ -41,10 +48,8 @@ public function setUp() {
    */
   function testAnalyzeBasic() {
     $this->drupalLogin($this->admin);
-    // Enable the frontpage view and click the analyse button.
-    $view = views_get_view('frontpage');
 
-    $this->drupalGet('admin/structure/views/view/frontpage/edit');
+    $this->drupalGet('admin/structure/views/view/test_view/edit');
     $this->assertLink(t('analyze view'));
 
     // This redirects the user to the analyze form.
diff --git a/core/modules/views/lib/Drupal/views/Tests/Handler/AreaTest.php b/core/modules/views/lib/Drupal/views/Tests/Handler/AreaTest.php
index a44ff6f..21804c5 100644
--- a/core/modules/views/lib/Drupal/views/Tests/Handler/AreaTest.php
+++ b/core/modules/views/lib/Drupal/views/Tests/Handler/AreaTest.php
@@ -175,7 +175,7 @@ public function testTitleArea() {
 
     $view->storage->enable()->save();
 
-    $this->drupalGet('frontpage');
+    $this->drupalGet('node');
     $this->assertText('Overridden title', 'Overridden title found.');
   }
 
diff --git a/core/modules/views/lib/Drupal/views/Tests/Handler/RelationshipTest.php b/core/modules/views/lib/Drupal/views/Tests/Handler/RelationshipTest.php
index 63cb46b..1b0741c 100644
--- a/core/modules/views/lib/Drupal/views/Tests/Handler/RelationshipTest.php
+++ b/core/modules/views/lib/Drupal/views/Tests/Handler/RelationshipTest.php
@@ -138,4 +138,5 @@ public function testRelationshipQuery() {
 
     $this->assertIdenticalResultset($view, $expected_result, $this->columnMap);
   }
+
 }
diff --git a/core/modules/views/lib/Drupal/views/Tests/Plugin/DisplayTest.php b/core/modules/views/lib/Drupal/views/Tests/Plugin/DisplayTest.php
index 4883ad5..6b023f7 100644
--- a/core/modules/views/lib/Drupal/views/Tests/Plugin/DisplayTest.php
+++ b/core/modules/views/lib/Drupal/views/Tests/Plugin/DisplayTest.php
@@ -19,7 +19,7 @@ class DisplayTest extends PluginTestBase {
    *
    * @var array
    */
-  public static $testViews = array('test_filter_groups', 'test_get_attach_displays');
+  public static $testViews = array('test_filter_groups', 'test_get_attach_displays', 'test_view');
 
   /**
    * Modules to enable.
@@ -56,7 +56,7 @@ public function setUp() {
    * @see Drupal\views_test_data\Plugin\views\display\DisplayTest
    */
   function testDisplayPlugin() {
-    $view = views_get_view('frontpage');
+    $view = views_get_view('test_view');
 
     // Add a new 'display_test' display and test it's there.
     $view->storage->addDisplay('display_test');
@@ -95,7 +95,7 @@ function testDisplayPlugin() {
     $this->assertTrue(strpos($output, '<h1>Test option title</h1>') !== FALSE, 'The test_option value found in display output title.');
 
     // Test that the display category/summary is in the UI.
-    $this->drupalGet('admin/structure/views/view/frontpage/edit/display_test_1');
+    $this->drupalGet('admin/structure/views/view/test_view/edit/display_test_1');
     $this->assertText('Display test settings');
 
     $this->clickLink('Test option title');
@@ -104,7 +104,7 @@ function testDisplayPlugin() {
     $this->drupalPost(NULL, array('test_option' => $this->randomString), t('Apply'));
 
     // Check the new value has been saved by checking the UI summary text.
-    $this->drupalGet('admin/structure/views/view/frontpage/edit/display_test_1');
+    $this->drupalGet('admin/structure/views/view/test_view/edit/display_test_1');
     $this->assertRaw($this->randomString);
 
     // Test the enable/disable status of a display.
diff --git a/core/modules/views/lib/Drupal/views/Tests/Plugin/PagerTest.php b/core/modules/views/lib/Drupal/views/Tests/Plugin/PagerTest.php
index 6be2dc8..5cd22a0 100644
--- a/core/modules/views/lib/Drupal/views/Tests/Plugin/PagerTest.php
+++ b/core/modules/views/lib/Drupal/views/Tests/Plugin/PagerTest.php
@@ -17,7 +17,7 @@ class PagerTest extends PluginTestBase {
    *
    * @var array
    */
-  public static $testViews = array('test_store_pager_settings', 'test_pager_none', 'test_pager_some', 'test_pager_full', 'test_view_pager_full_zero_items_per_page');
+  public static $testViews = array('test_store_pager_settings', 'test_pager_none', 'test_pager_some', 'test_pager_full', 'test_view_pager_full_zero_items_per_page', 'test_view');
 
   /**
    * Modules to enable.
@@ -44,13 +44,16 @@ public function testStorePagerSettings() {
     $this->drupalLogin($admin_user);
     // Test behaviour described in http://drupal.org/node/652712#comment-2354918.
 
-    $this->drupalGet('admin/structure/views/view/frontpage/edit');
-
+    $this->drupalGet('admin/structure/views/view/test_view/edit');
 
     $edit = array(
+      'pager[type]' => 'full',
+    );
+    $this->drupalPost('admin/structure/views/nojs/display/test_view/default/pager', $edit, t('Apply'));
+    $edit = array(
       'pager_options[items_per_page]' => 20,
     );
-    $this->drupalPost('admin/structure/views/nojs/display/frontpage/default/pager_options', $edit, t('Apply'));
+    $this->drupalPost('admin/structure/views/nojs/display/test_view/default/pager_options', $edit, t('Apply'));
     $this->assertText('20 items');
 
     // Change type and check whether the type is new type is stored.
@@ -58,8 +61,8 @@ public function testStorePagerSettings() {
     $edit = array(
       'pager[type]' => 'mini',
     );
-    $this->drupalPost('admin/structure/views/nojs/display/frontpage/default/pager', $edit, t('Apply'));
-    $this->drupalGet('admin/structure/views/view/frontpage/edit');
+    $this->drupalPost('admin/structure/views/nojs/display/test_view/default/pager', $edit, t('Apply'));
+    $this->drupalGet('admin/structure/views/view/test_view/edit');
     $this->assertText('Mini', 'Changed pager plugin, should change some text');
 
     // Test behaviour described in http://drupal.org/node/652712#comment-2354400
diff --git a/core/profiles/minimal/minimal.install b/core/profiles/minimal/minimal.install
index 0c3aafb..cc47f49 100644
--- a/core/profiles/minimal/minimal.install
+++ b/core/profiles/minimal/minimal.install
@@ -14,9 +14,6 @@
 function minimal_install() {
   $default_theme = 'stark';
 
-  // Set front page to "node".
-  config('system.site')->set('page.front', 'node')->save();
-
   // Allow visitor account creation, but with administrative approval.
   config('user.settings')->set('register', USER_REGISTER_VISITORS_ADMINISTRATIVE_APPROVAL)->save();
 

diff --git a/core/modules/views/lib/Drupal/views/Tests/UI/DefaultViewsTest.php b/core/modules/views/lib/Drupal/views/Tests/UI/DefaultViewsTest.php
index 2780e40..dfdeed5 100644
--- a/core/modules/views/lib/Drupal/views/Tests/UI/DefaultViewsTest.php
+++ b/core/modules/views/lib/Drupal/views/Tests/UI/DefaultViewsTest.php
@@ -31,34 +31,34 @@ public static function getInfo() {
    * Tests default views.
    */
   function testDefaultViews() {
-    // Make sure the front page view starts off as disabled (does not appear on
-    // the listing page).
-    $edit_href = 'admin/structure/views/view/frontpage/edit';
+    // Make sure the view starts off as disabled (does not appear on the listing
+    // page).
+    $edit_href = 'admin/structure/views/view/glossary/edit';
     $this->drupalGet('admin/structure/views');
     // @todo Disabled default views do now appear on the front page. Test this
     // behavior with templates instead.
     // $this->assertNoLinkByHref($edit_href);
 
-    // Enable the front page view, and make sure it is now visible on the main
-    // listing page.
+    // Enable the view, and make sure it is now visible on the main listing
+    // page.
     $this->drupalGet('admin/structure/views');
-    $this->clickViewsOperationLink(t('Enable'), '/frontpage/');
+    $this->clickViewsOperationLink(t('Enable'), '/glossary/');
     $this->assertUrl('admin/structure/views');
     $this->assertLinkByHref($edit_href);
 
     // It should not be possible to revert the view yet.
     // @todo Figure out how to handle this with the new configuration system.
     // $this->assertNoLink(t('Revert'));
-    // $revert_href = 'admin/structure/views/view/frontpage/revert';
+    // $revert_href = 'admin/structure/views/view/glossary/revert';
     // $this->assertNoLinkByHref($revert_href);
 
     // Edit the view and change the title. Make sure that the new title is
     // displayed.
     $new_title = $this->randomName(16);
     $edit = array('title' => $new_title);
-    $this->drupalPost('admin/structure/views/nojs/display/frontpage/page_1/title', $edit, t('Apply'));
-    $this->drupalPost('admin/structure/views/view/frontpage/edit/page_1', array(), t('Save'));
-    $this->drupalGet('frontpage');
+    $this->drupalPost('admin/structure/views/nojs/display/glossary/page_1/title', $edit, t('Apply'));
+    $this->drupalPost('admin/structure/views/view/glossary/edit/page_1', array(), t('Save'));
+    $this->drupalGet('glossary');
     $this->assertResponse(200);
     $this->assertText($new_title);
 
@@ -77,22 +77,22 @@ function testDefaultViews() {
     // $this->assertLink(t('Revert'));
     // $this->assertLinkByHref($revert_href);
     // $this->drupalPost($revert_href, array(), t('Revert'));
-    // $this->drupalGet('frontpage');
+    // $this->drupalGet('glossary');
     // $this->assertNoText($new_title);
 
     // Clone the view and check that the normal schema of cloned views is used.
     $this->drupalGet('admin/structure/views');
-    $this->clickViewsOperationLink(t('Clone'), '/frontpage');
+    $this->clickViewsOperationLink(t('Clone'), '/glossary');
     $edit = array(
-      'id' => 'clone_of_frontpage',
+      'id' => 'clone_of_glossary',
     );
-    $this->assertTitle(t('Clone of @human_name | @site-name', array('@human_name' => 'Front page', '@site-name' => config('system.site')->get('name'))));
+    $this->assertTitle(t('Clone of @human_name | @site-name', array('@human_name' => 'Glossary', '@site-name' => config('system.site')->get('name'))));
     $this->drupalPost(NULL, $edit, t('Clone'));
-    $this->assertUrl('admin/structure/views/view/clone_of_frontpage/edit', array(), 'The normal cloning name schema is applied.');
+    $this->assertUrl('admin/structure/views/view/clone_of_glossary/edit', array(), 'The normal cloning name schema is applied.');
 
     // Clone a view and set a custom name.
     $this->drupalGet('admin/structure/views');
-    $this->clickViewsOperationLink(t('Clone'), '/frontpage');
+    $this->clickViewsOperationLink(t('Clone'), '/glossary');
     $random_name = strtolower($this->randomName());
     $this->drupalPost(NULL, array('id' => $random_name), t('Clone'));
     $this->assertUrl("admin/structure/views/view/$random_name/edit", array(), 'The custom view name got saved.');
@@ -102,19 +102,19 @@ function testDefaultViews() {
     // listing page.
     // @todo Test this behavior with templates instead.
     $this->drupalGet('admin/structure/views');
-    $this->clickViewsOperationLink(t('Disable'), '/frontpage/');
+    $this->clickViewsOperationLink(t('Disable'), '/glossary/');
     // $this->assertUrl('admin/structure/views');
     // $this->assertNoLinkByHref($edit_href);
     // The easiest way to verify it appears on the disabled views listing page
     // is to try to click the "enable" link from there again.
     $this->drupalGet('admin/structure/views');
-    $this->clickViewsOperationLink(t('Enable'), '/frontpage/');
+    $this->clickViewsOperationLink(t('Enable'), '/glossary/');
     $this->assertUrl('admin/structure/views');
     $this->assertLinkByHref($edit_href);
 
     // Test deleting a view.
     $this->drupalGet('admin/structure/views');
-    $this->clickViewsOperationLink(t('Delete'), '/frontpage/');
+    $this->clickViewsOperationLink(t('Delete'), '/glossary/');
     // Submit the confirmation form.
     $this->drupalPost(NULL, array(), t('Delete'));
     // Ensure the view is no longer listed.
@@ -165,7 +165,7 @@ function testSplitListing() {
    * @param $unique_href_part
    *   A unique string that is expected to occur within the href of the desired
    *   link. For example, if the link URL is expected to look like
    *   "admin/structure/views/view/frontpage/...", then "/frontpage/" could be
    *   passed as the expected unique string.
    *
    * @return
@@ -165,7 +165,7 @@ function testSplitListing() {
    *   A unique string that is expected to occur within the href of the desired
    *   link. For example, if the link URL is expected to look like
-   *   "admin/structure/views/view/frontpage/...", then "/frontpage/" could be
+   *   "admin/structure/views/view/glossary/...", then "/glossary/" could be
    *   passed as the expected unique string.
    *